Module detect

Module detect 

Filesystem-derived pool state detection

Instead of maintaining an inventory.json file, pool state is derived from the filesystem: directory existence determines pool membership, and marker files in the per-worktree git dir determine status.

Structs

PoolEntry
A single worktree entry derived from filesystem scan
PoolState
Snapshot of the pool state, derived from the filesystem

Enums

PoolNextAction
Recommended next action for pool management
WorktreeStatus
Status of a worktree in the pool, derived from filesystem state