PoolState

Struct PoolState 

pub struct PoolState {
    pub entries: Vec<PoolEntry>,
}
Snapshot of the pool state, derived from the filesystem

Fields

entries: Vec<PoolEntry>

Implementations

Source

impl PoolState

pub fn scan( worktrees_dir: &Path, acquired_dir: &Path, prefix: &str, ) -> Result<Self>

Scan the filesystem to build pool state.

  • worktrees_dir: path to .worktrees/
  • acquired_dir: path to the acquired markers directory
  • prefix: directory name prefix to filter (e.g., “web-2-pool-”)
pub fn count_by_status(&self, status: &WorktreeStatus) -> usize

Count worktrees with a given status

pub fn find_available(&self) -> Option<&PoolEntry>

Find the first available worktree

pub fn find_by_name_or_path(&self, identifier: &str) -> Option<&PoolEntry>

Find a worktree by name or path

pub fn next_name(&self, prefix: &str) -> String

Find the next pool name based on existing entries. Returns {prefix}NNN (e.g., “web-2-pool-003”).

pub fn next_action(&self) -> PoolNextAction

Determine the recommended next action