PoolLock

Struct PoolLock 

pub struct PoolLock { /* private fields */ }
A held file lock on the pool

Implementations

Source

impl PoolLock

pub fn acquire(pool_dir: &Path) -> Result<Self>

Acquire an exclusive lock on the pool directory with retry. Creates the pool directory and lock file if they don’t exist. Retries for up to 10 seconds before returning PoolLockTimeout.

pub fn acquire_with_timeout(pool_dir: &Path, timeout: Duration) -> Result<Self>

Acquire an exclusive lock with a custom timeout.